@@ -16,7 +16,7 @@ dependencies {
     libs("com.restlet.client:commons:2.0.0")
 }
 
-task<Copy>("copyLibs") {
+tasks.register<Copy>("copyLibs") {
     from(libs)
     into("$buildDir/libs")
 }
