@@ -1,12 +1,12 @@
 // tag::declare-task[]
-task<Copy>("myCopy")
+tasks.register<Copy>("myCopy")
 // end::declare-task[]
 
 // tag::configure[]
 // Configure task using Kotlin delegated properties and a lambda
-val myCopy by tasks.getting(Copy::class) {
+val myCopy by tasks.existing(Copy::class) {
     from("resources")
     into("target")
 }
-myCopy.include("**/*.txt", "**/*.xml", "**/*.properties")
+myCopy { include("**/*.txt", "**/*.xml", "**/*.properties") }
 // end::configure[]
